Scalene

AI optimization options
AI service provider:

OpenAI API key:
Language model:
Azure OpenAI API key:
API URL Azure Open AI:
Language model:
API Version:
AWS Access Key ID:
AWS Secret Access Key:
AWS Region:
Language model:
Use this option if you are running a local language model. We currently support Ollama.
IP Address: Port:
Server not found or no language models installed.
Install language models as in `ollama pull codellama:34b-python`.
Language model:
Proposed optimizations
Optimize runtime performance
Optimize memory efficiency
Include GPU optimizations
Click on an explosion (💥) to see proposed optimizations for a region of code,
or on a lightning bolt (⚡) to propose optimizations for a specific line.
Click again to generate a different one.
Note that optimizations are AI-generated and may not be correct.